<?php

/**
 * An article.
 *
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubapi
 * @version 0.8.3
 */
class OnpubArticle
{
    private $ID;
    private $imageID;
    private $title;
    private $content;
    private $url;
    private $created;
    private $modified;
    private $authors;
    private $image;
    private $sectionIDs;

    /**
     * Construct a new article.
     */
    function __construct()
    {
        $this->ID = null;
        $this->imageID = null;
        $this->title = "";
        $this->content = "";
        $this->url = "";
        $this->created = new OnpubDateTime();
        $this->modified = new OnpubDateTime();
        $this->authors = array();
        $this->image = null;
        $this->sectionIDs = array();
    }

    /**
     * Get this article's ID.
     *
     * By default, returns NULL.
     *
     * @return int
     */
    public function getID()
    {
        return $this->ID;
    }

    /**
     * Set this article's ID.
     *
     * @param int
     */
    public function setID( $ID )
    {
        $this->ID = $ID;
    }

    /**
     * Get this article's imageID.
     *
     * By default, returns NULL.
     *
     * @return int
     */
    public function getImageID()
    {
        return $this->imageID;
    }

    /**
     * Set this article's imageID.
     *
     * @param int
     */
    public function setImageID( $imageID )
    {
        $this->imageID = $imageID;
    }

    /**
     * Get this article's title.
     *
     * By default, returns an empty string.
     *
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Set this article's title.
     *
     * @param string
     */
    public function setTitle( $title )
    {
        $this->title = $title;
    }

    /**
     * Get this article's content.
     *
     * By default, returns an empty string.
     *
     * @return string
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * Set this article's content.
     *
     * @param string
     */
    public function setContent( $content )
    {
        $this->content = $content;
    }

    /**
     * Get this article's creation date.
     *
     * By default, returns the date at the time this object was constructed.
     *
     * @return OnpubDateTime
     */
    public function getCreated()
    {
        return $this->created;
    }

    /**
     * Set this article's creation date.
     *
     * @param OnpubDateTime
     */
    public function setCreated( OnpubDateTime $created )
    {
        $this->created = $created;
    }

    /**
     * Get this article's last modification date.
     *
     * By default, returns the date at the time this object was constructed.
     *
     * @return OnpubDateTime
     */
    public function getModified()
    {
        return $this->modified;
    }

    /**
     * Set this article's last modification date.
     *
     * @param OnpubDateTime
     */
    public function setModified( OnpubDateTime $modified )
    {
        $this->modified = $modified;
    }

    /**
     * Get this article's image.
     *
     * If this article's imageID is not NULL this method will return the
     * {@link OnpubImage} which corresponds to the row in the
     * {@link OnpubImages} table with this article's imageID. This returns
     * an object equivalent to one you would get by calling
     * {@link OnpubImages::get()} with this article's imageID as the
     * argument. This method is provided for speed and convenience. This method
     * will always return NULL if this object was fetched from an array
     * returned by the {@link OnpubArticles::select()} method. This method
     * will also return NULL if this article does not refer to an image in the
     * database (i.e. it has no image). This method will always return NULL if
     * {@link getImageID()} returns NULL.
     *
     * @return OnpubImage
     */
    public function getImage()
    {
        return $this->image;
    }

    /**
     * Set this article's image.
     *
     * @param OnpubImage
     */
    public function setImage( OnpubImage $image )
    {
        $this->image = $image;
    }

    /**
     * Get this article's author(s).
     *
     * By default, returns an empty array.
     *
     * @return array Array of {@link OnpubAuthor} objects.
     */
    public function getAuthors()
    {
        return $this->authors;
    }

    /**
     * Set this article's author(s).
     *
     * @param array Array of {@link OnpubAuthor} objects.
     */
    public function setAuthors( $authors )
    {
        $this->authors = $authors;
    }

    /**
     * Get this article's sectionID(s).
     *
     * By default, returns an empty array.
     *
     * @return array Array of ints.
     */
    public function getSectionIDs()
    {
        return $this->sectionIDs;
    }

    /**
     * Set this article's sectionID(s).
     *
     * @param array Array of ints.
     */
    public function setSectionIDs( $sectionIDs )
    {
        $this->sectionIDs = $sectionIDs;
    }

    /**
     * Append a sectionID to this article's sectionIDs array.
     *
     * @param int
     */
    public function appendSectionID( $sectionID )
    {
        $this->sectionIDs[] = $sectionID;
    }

    /**
     * Get a 1-2 paragraph summary of this article.
     *
     * Uses this article's content field to generate a summary.
     *
     * @return string
     */
    public function getSummary( $limit = 30 )
    {
        $summary = "";
        $words = explode( " ", trim( strip_tags( $this->content ) ) );

        for ( $i = 0; $i < sizeof( $words ) && $i < $limit; $i++ ) {
            $summary .= " " . trim( $words[$i] );
        }

        return $summary;
    }

    /**
     * Get this article's URL.
     *
     * By default, returns an empty string.
     *
     * @return string
     */
    public function getURL()
    {
        return $this->url;
    }

    /**
     * Set this article's URL.
     *
     * @param string
     */
    public function setURL( $url )
    {
        $this->url = $url;
    }
}

?>
