<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubapi
 * @version 0.8.3
 */
class OnpubDatabase
{
    const MYSQL_TABLES_CREATE_FILE = 'api/sql/create_onpub_mysql_tables.sql';
    const MYSQL_TABLES_DELETE_FILE = 'api/sql/delete_onpub_mysql_tables.sql';
    const SQLITE_TABLES_CREATE_FILE = 'api/sql/create_onpub_sqlite_tables.sql';
    const SQLITE_TABLES_DELETE_FILE = 'api/sql/delete_onpub_sqlite_tables.sql';
    private $pdo;

    /**
     * @param PDO $pdo A {@link PHP_MANUAL#function.pdo-construct PHP Data Object}
     */
    function __construct( PDO $pdo )
    {
        $this->pdo = $pdo;
        $this->pdo->setAttribute( PDO::ATTR_EMULATE_PREPARES, true );
    }

    public function backup()
    {
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oauthors = new OnpubAuthors( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );

        $queryOptions = new OnpubQueryOptions();
        $rowLimit = 100;
        $queryOptions->setPage( 1, $rowLimit );

        $now = new OnpubDateTime();
        $time = str_replace( ' ', '-', $now->getTextualDateTime() );
        $time = str_replace( ',', '', $time );
        $time = str_replace( ':', '-', $time );
        $servername = str_replace( '.', '-', $_SERVER['SERVER_NAME'] );
        $prefix = "onpub-tables_" . $servername . "_" . $time;
        $suffix = ".sq3";
        $tempname = tempnam( '/tmp' , $prefix ) . $suffix;

        if ( touch( $tempname ) ) {
            try {
                $sqlite = new PDO( "sqlite:" . $tempname, '', '' );
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $odatabase = new OnpubDatabase( $sqlite );

            try {
                $odatabase->install();
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $liteaamaps = new OnpubAAMaps( $sqlite );
            $litearticles = new OnpubArticles( $sqlite );
            $liteauthors = new OnpubAuthors( $sqlite );
            $liteimages = new OnpubImages( $sqlite );
            $litesamaps = new OnpubSAMaps( $sqlite );
            $litesections = new OnpubSections( $sqlite );
            $litewebsites = new OnpubWebsites( $sqlite );
            $litewsmaps = new OnpubWSMaps( $sqlite );

            while ( sizeof( ($aamaps = $oaamaps->select( $queryOptions )) ) ) {
                $result = $liteaamaps->insert( $aamaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $aamaps = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($articles = $oarticles->select( $queryOptions )) ) ) {
                $litearticles->insert( $articles );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $articles = null;
            }


            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($authors = $oauthors->select( $queryOptions )) ) ) {
                $liteauthors->insert( $authors );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $authors = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($images = $oimages->select( $queryOptions )) ) ) {
                $liteimages->insert( $images );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $images = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($samaps = $osamaps->select( $queryOptions )) ) ) {
                $litesamaps->insert( $samaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $samaps = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            try {
                while ( sizeof( ($sections = $osections->select( $queryOptions )) ) ) {
                    $litesections->insert( $sections );
                    $page++;
                    $queryOptions->setPage( $page, $rowLimit );
                    $sections = null;
                }
            }
            catch ( PDOException $e ) {
                throw $e;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($websites = $owebsites->select( $queryOptions )) ) ) {
                $litewebsites->insert( $websites );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $websites = null;
            }

            $page = 1;
            $queryOptions->setPage( $page, $rowLimit );

            while ( sizeof( ($wsmaps = $owsmaps->select( $queryOptions )) ) ) {
                $litewsmaps->insert( $wsmaps );
                $page++;
                $queryOptions->setPage( $page, $rowLimit );
                $wsmaps = null;
            }
        }
        else {
            // probably should throw an exception or something here
            return false;
        }

        $newname = str_replace( '-tmp-', '', $tempname );

        $offset = 0;
        $pos = 0;

        while ( ($pos = strpos( $newname, '-', $offset )) !== false ) {
            $offset = $pos + 1;
        }

        $offset--;
        $pos = strpos( $newname, '.' );

        $newname = substr_replace( $newname, '', $offset, $pos - $offset );

        if ( rename( $tempname, $newname ) ) {
            return $newname;
        }

        return false;
    }

    public function delete()
    {
        $sqlfile = array();
        $line = 0;

        switch ( $this->pdo->getAttribute( PDO::ATTR_DRIVER_NAME ) ) {
            case "mysql":
            $sqlfile = file( OnpubDatabase::MYSQL_TABLES_DELETE_FILE );
            break;
            case "sqlite":
            $sqlfile = file( OnpubDatabase::SQLITE_TABLES_DELETE_FILE );
            break;
        }

        // advance past all comments
        while ( strpos( $sqlfile[$line], '--' ) !== false ) {
            $line++;

            while ( $sqlfile[$line] == "\n" ) {
                $line++;
            }
        }

        for ( $i = $line; $i < sizeof( $sqlfile ); $i++ ) {
            $query = '';

            while ( strpos( $sqlfile[$i], ';' ) === false ) {
                $query .= $sqlfile[$i];
                $i++;
            }

            $query .= $sqlfile[$i];

            if ( ($i + 1) < sizeof( $sqlfile ) ) {
                while ( $sqlfile[$i + 1] == "\n" ) {
                    $i++;
                }
            }

            $result = null; $result = $this->pdo->exec( $query );
            OnpubDatabase::verifyExec( $this->pdo, $result, false );
        }

        return true;
    }

    public function install()
    {
        $sqlfile = array();
        $line = 0;

        switch ( $this->pdo->getAttribute( PDO::ATTR_DRIVER_NAME ) ) {
            case "mysql":
            $sqlfile = file( OnpubDatabase::MYSQL_TABLES_CREATE_FILE );
            break;
            case "sqlite":
            $sqlfile = file( OnpubDatabase::SQLITE_TABLES_CREATE_FILE );
            break;
        }

        // advance past all comments
        while ( strpos( $sqlfile[$line], '--' ) !== false ) {
            $line++;

            while ( $sqlfile[$line] == "\n" ) {
                $line++;
            }
        }

        for ( $i = $line; $i < sizeof( $sqlfile ); $i++ ) {
            $query = '';

            while ( strpos( $sqlfile[$i], ';' ) === false ) {
                $query .= $sqlfile[$i];
                $i++;
            }

            $query .= $sqlfile[$i];

            if ( ($i + 1) < sizeof( $sqlfile ) ) {
                while ( $sqlfile[$i + 1] == "\n" ) {
                    $i++;
                }
            }

            $result = null; $result = $this->pdo->exec( $query );
            OnpubDatabase::verifyExec( $this->pdo, $result, false );
        }

        return true;
    }

    public function status()
    {
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oauthors = new OnpubAuthors( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );
        $queryOptions = new OnpubQueryOptions( $this->pdo );
        $queryOptions->setPage( 1, 1 );

        try {
            $oaamaps->select( $queryOptions );
            $oarticles->select( $queryOptions );
            $oauthors->select( $queryOptions );
            $oimages->select( $queryOptions );
            $osamaps->select( $queryOptions );
            $osections->select( $queryOptions );
            $owebsites->select( $queryOptions );
            $owsmaps->select( $queryOptions );
        }
        catch ( PDOException $e ) {
            $sqlstate = $e->errorInfo[0];

            switch ( $sqlstate ) {
                case "42S02": // mysql
                return false;
                case "HY000": // sqlite
                return false;
            }

            throw $e;
        }

        return true;
    }

    public static function verifyExecute( PDO $pdo, $result, $isTransaction, $errorInfo )
    {
        if ( $isTransaction ) {
            if ( !$result ) {
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( !$result ) {
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    public static function verifyExec( PDO $pdo, $result, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( $result === false ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    public static function verifyQuery( PDO $pdo, $result, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( !$result ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( !$result ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    public static function verifyStatus( PDO $pdo, $status )
    {
        if ( !$status ) {
            $errorInfo = $pdo->errorInfo();
            $e = new PDOException( $errorInfo[2], $errorInfo[1] );
            $e->errorInfo = $errorInfo;
            throw $e;
        }
    }

    public static function verifyPrepare( PDO $pdo, $stmt, $isTransaction )
    {
        if ( $isTransaction ) {
            if ( $stmt === false ) {
                $errorInfo = $pdo->errorInfo();
                $status = $pdo->rollBack();

                if ( !$status ) {
                    $errorInfo = $pdo->errorInfo();
                    $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                    $e->errorInfo = $errorInfo;
                    throw $e;
                }

                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
        else {
            if ( $stmt === false ) {
                $errorInfo = $pdo->errorInfo();
                $e = new PDOException( $errorInfo[2], $errorInfo[1] );
                $e->errorInfo = $errorInfo;
                throw $e;
            }
        }
    }

    /**
     * Used internally for decoding UTF8 to latin1.
     */
    public static function utf8Decode($in_str)
    {
       // utf8Decode is courtesy nospam@jra.nu and was found
       // at: http://us4.php.net/utf8-decode in the comments section
       // Replace ? with a unique string
       $new_str = str_replace("?", "q0u0e0s0t0i0o0n", $in_str);

       // Try the utf8_decode
       $new_str=utf8_decode($new_str);

       // if it contains ? marks
       if (strpos($new_str,"?") !== false)
       {
           // Something went wrong, set new_str to the original string.
           $new_str=$in_str;
       }
       else
       {
           // If not then all is well, put the ?-marks back where is belongs
           $new_str = str_replace("q0u0e0s0t0i0o0n", "?", $new_str);
       }

       return $new_str;
    }
}

?>
