<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubArticleEdit
{
    private $pdo;
    private $oarticle;
    private $tidyConfig;
    private $nltobr;
    private $delbr;

    function __construct( PDO $pdo, OnpubArticle $oarticle, $tidyConfig = array(), $nltobr = "0", $delbr = "0" )
    {
        $this->pdo = $pdo;
        $this->oarticle = $oarticle;
        $this->tidyConfig = $tidyConfig;
        $this->nltobr = $nltobr;
        $this->delbr = $delbr;
    }

    public function display()
    {
        $oarticles = new OnpubArticles( $this->pdo );
        $oaamaps = new OnpubAAMaps( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );
        $osections = new OnpubSections( $this->pdo );

        try {
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setIncludeAuthors( true );
            $this->oarticle = $oarticles->get( $this->oarticle->getID(), $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "fileName" );
            $queryOptions->setOrder( "ASC" );
            $images = $oimages->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "name" );
            $queryOptions->setOrder( "ASC" );
            $websites = $owebsites->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $samaps = $osamaps->select( $queryOptions, null, $this->oarticle->getID() );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $author = $this->oarticle->getAuthors();

        if ( sizeof( $author ) ) {
            $author = $author[0];
        }
        else {
            $author = new OnpubAuthor();
        }

        $widget = new OnpubHeaderWidget( "Article Editor" );
        $widget->display();

        include("gui/fckeditor/fckeditor.php");

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table cellspacing="0" cellpadding="5" border="0">' . "\n";

        echo '<tr>' . "\n";
        echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" width="60" height="25" border="0" alt="Save" title="Save" /></a> <a href="javascript:articleDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" width="60" height="25" border="0" alt="Delete" title="Delete" /></a> <a href="javascript:articleView();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'view.gif" width="60" height="25" border="0" alt="View" title="View" /></a></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Title</b><br /><input type="text" maxlength="255" size="75" name="title" value="' . htmlentities( $this->oarticle->getTitle() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Author</b><br /><input type="text" maxlength="255" size="75" name="displayAs" value="' . htmlentities( $author->getDisplayAs() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";

        echo '<td><b>Content</b><br />' . "\n";

        $oFCKeditor = new FCKeditor('content');
        $oFCKeditor->BasePath = 'gui/fckeditor/';
        $oFCKeditor->Value = $this->oarticle->getContent();
        $oFCKeditor->Width = '830';
        $oFCKeditor->Height = '330';
        $oFCKeditor->Config["CustomConfigurationsPath"] = '../../js/fckconfig.js';
        $oFCKeditor->Create();

/*
        if ( $this->nltobr == "1" ) {
            echo '<input type="checkbox" id="id_nltobr" name="nltobr" value="1" checked="checked" /> <label for="id_nltobr">Automatically insert a break tag for each line break</label><br />' . "\n";
        }
        else {
            echo '<input type="checkbox" id="id_nltobr" name="nltobr" value="1" /> <label for="id_nltobr">Automatically insert a break tag for each line break</label><br />' . "\n";
        }

        if ( $this->delbr == "1" ) {
            echo '<input type="checkbox" id="id_delbr" name="delbr" value="1" checked="checked" /> <label for="id_delbr">Delete all break tags</label><br />' . "\n";
        }
        else {
            echo '<input type="checkbox" id="id_delbr" name="delbr" value="1" /> <label for="id_delbr">Delete all break tags</label><br />' . "\n";
        }
*/

        echo '</td>' . "\n";
        echo '</tr>' . "\n";

        if ( function_exists( "tidy_repair_string" ) ) {
            echo '<tr>' . "\n";
            echo '<td><b>HTML Tidy</b><br />' . "\n";

            if ( $this->tidyConfig["markup"] ) {
                echo '<input type="checkbox" id="id_markup" name="markup" value="1" checked="checked" /> <label for="id_markup">Tidy HTML in Content</label><br />' . "\n";
            }
            else {
                echo '<input type="checkbox" id="id_markup" name="markup" value="1" /> <label for="id_markup">Tidy HTML in Content</label><br />' . "\n";
            }

            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->oarticle->getID() . '</td>' . "\n";
        echo '</tr>' . "\n";

        $widget = new OnpubCreatedWidget( $this->oarticle->getCreated() );
        $widget->display();

        $modified = $this->oarticle->getModified();

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $modified->getTextualDateTime() . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>URL</b><br /><input type="text" maxlength="255" size="75" name="url" value="' . htmlentities( $this->oarticle->getURL() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";
/*
        $widget = new OnpubImagesWidget( "Image", $this->oarticle->getImageID(), $images );
        $widget->display();
*/
        $widget = new OnpubSectionsWidget( null, $websites, $osections, $samaps );
        $widget->display();

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="ID" value="' . $this->oarticle->getID() . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="imageID" value="' . $this->oarticle->getImageID() . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="authorID" value="' . $author->getID() . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="authorImageID" value="' . $author->getImageID() . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="lastDisplayAs" value="' . htmlentities( $author->getDisplayAs() ) . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="onpub" value="ArticleEditProcess" /></div>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubFooterWidget();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->oarticle->getTitle() ) {
            $this->oarticle->setTitle( null );
            return false;
        }

        return true;
    }

    public function process()
    {
        $oarticles = new OnpubArticles( $this->pdo );

        $content = OnpubDatabase::utf8Decode( $this->oarticle->getContent() );

        if ( $this->nltobr == "1" ) {
            $content = nl2br( $content );
        }

        if ( $this->delbr == "1" ) {
            $content = str_ireplace( "<br>", "", $content );
            $content = str_ireplace( "<br />", "", $content );
        }

        if ( function_exists( "tidy_repair_string" ) ) {
            if ( $this->tidyConfig["markup"] ) {
                $content = tidy_repair_string( $content, $this->tidyConfig, "latin1" );
            }
        }

        $this->oarticle->setContent( $content );

        try {
            $oarticles->update( $this->oarticle, true );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $oarticles = new OnpubArticles( $this->pdo );

        try {
            $oarticles->delete( $this->oarticle->getID() );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>
