<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubImageEdit
{
    private $pdo;
    private $oimage;
    private $oldImageFileName;

    function __construct( PDO $pdo, OnpubImage $oimage, $oldImageFileName = null )
    {
        $this->pdo = $pdo;
        $this->oimage = $oimage;
        $this->oldImageFileName = $oldImageFileName;
    }

    public function display()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $imageFileSize = null;
        $imageWidth = null;
        $imageHeight = null;
        $imageDimensions = null;
        $imageFileInfo = null;
        $fileExists = false;

        try {
            $this->oimage = $oimages->get( $this->oimage->getID(), false );
            $website = $owebsites->get( $this->oimage->getWebsiteID(), false );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        if ( $fileExists = file_exists( $website->getImagesDirectory() . $this->oimage->getFileName() ) ) {
            $imageDimensions = getimagesize( $website->getImagesDirectory() . $this->oimage->getFileName() );
            $imageFileInfo = stat( $website->getImagesDirectory() . $this->oimage->getFileName() );
        }

        if ( $imageFileInfo ) {
            $imageFileSize = $imageFileInfo[7];
        }

        if ( $imageDimensions ) {
            $imageWidth = $imageDimensions[0];
            $imageHeight = $imageDimensions[1];
        }

        $widget = new OnpubHeaderWidget( "Image Editor" );
        $widget->display();

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";

        echo '<tr>' . "\n";
        echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" border="0" alt="" /></a> <a href="javascript:imageDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" border="0" alt="" /></a></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->oimage->getID() . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->oimage->getCreated()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->oimage->getModified()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>File Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="fileName" value="' . htmlentities( $this->oimage->getFileName() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        if ( @fopen( $website->getImagesURL() . rawurlencode( $this->oimage->getFileName() ), 'r' ) ) {
            echo '<tr>' . "\n";
            echo '<td><b>URL</b><br /><a href="' . $website->getImagesURL() . $this->oimage->getFileName() . '" target="_blank">' . $website->getImagesURL() . $this->oimage->getFileName() . '</a></td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<a href="' . $website->getImagesURL() . $this->oimage->getFileName() . '" target="_blank"><img src="' . $website->getImagesURL() . $this->oimage->getFileName() . '" width="' . $imageWidth . '" height="' . $imageHeight . '" alt="' . $this->oimage->getFileName() . '" title="' . $this->oimage->getFileName() . '" border="0" /></a>' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>URL</b><br /><a href="' . $website->getImagesURL() . $this->oimage->getFileName() . '" target="_blank">' . $website->getImagesURL() . $this->oimage->getFileName() . '</a><span class="error"> &laquo; not found</span><br /><span class="tip">Tip:</span> make sure the Images URL of <a href="index.php?onpub=WebsiteEdit&amp;websiteID=' . $website->getID() . '">' . $website->getName() . '</a> is configured correctly.</td>' . "\n";
            echo '</tr>' . "\n";
        }



        echo '<tr>' . "\n";
        echo '<td><b>Description</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="description" value="' . htmlentities( $this->oimage->getDescription() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Website</b><br /><a href="index.php?onpub=WebsiteEdit&amp;websiteID=' . $website->getID() . '" title="Edit">' . $website->getName() . '</a></td>' . "\n";
        echo '</tr>' . "\n";

        if ( $fileExists ) {
            echo '<tr>' . "\n";
            echo '<td><b>File Path</b><br />' . $website->getImagesDirectory() . $this->oimage->getFileName() . ' (on <i>' . $_SERVER['SERVER_NAME'] . '</i>)</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>Width</b><br />' . "\n";
            echo $imageWidth . 'px' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>Height</b><br />' . "\n";
            echo $imageHeight . 'px' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";

            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<b>File Size</b><br />' . "\n";

            if ( $imageFileSize >= 1024 ) {
                echo round( ($imageFileSize / 1024) ) . ' KB (' . $imageFileSize . ' bytes)' . "\n";
            }
            else {
                echo $imageFileSize . ' bytes' . "\n";
            }

            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
/*
            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<span class="error">Can\'t display image properties, make sure <a href="index.php?onpub=WebsiteEdit&amp;websiteID=' . $website->getID() . '" title="Edit">' . $website->getName() . '</a>\'s <b>Images Directory</b> is setup correctly.</span>' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
*/
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="ImageEditProcess" /></div>' . "\n";
        echo '<div><input type="hidden" name="imageID" value="' . $this->oimage->getID() . '" /></div>' . "\n";
        echo '<div><input type="hidden" name="oldImageFileName" value="' . htmlentities( $this->oimage->getFileName() ) . '" /></div>' . "\n";

        echo '</form>' . "\n";

        $widget = new OnpubFooterWidget();
        $widget->display();
    }

    public function validate()
    {
        return true;
    }

    public function process()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );

        $image = $oimages->get( $this->oimage->getID(), false );
        $website = $owebsites->get( $image->getWebsiteID(), false );

        if ( $this->oimage->getFileName() != $this->oldImageFileName ) {
            if ( file_exists( $website->getImagesDirectory() . $this->oldImageFileName ) ) {
                rename( $website->getImagesDirectory() . $this->oldImageFileName, $website->getImagesDirectory() . $this->oimage->getFileName() );
            }
        }

        try {
            $oimages->update( $this->oimage );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $oimages = new OnpubImages( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $this->oimage = $oimages->get( $this->oimage->getID(), false );
        $website = $owebsites->get( $this->oimage->getWebsiteID(), false );

        try {
            $oimages->delete( $this->oimage->getID() );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        if ( file_exists( unlink( $website->getImagesDirectory() . $this->oimage->getFileName() ) ) ) {
            unlink( $website->getImagesDirectory() . $this->oimage->getFileName() );
        }
    }
}

?>
