<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubSectionCreate
{
    private $pdo;
    private $osection;
    private $public;

    function __construct( PDO $pdo, OnpubSection $osection, $public = false )
    {
        $this->pdo = $pdo;
        $this->osection = $osection;
        $this->public = $public;
    }

    public function display()
    {
        $owebsites = new OnpubWebsites( $this->pdo );
        $osections = new OnpubSections( $this->pdo );

        try {
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "name" );
            $queryOptions->setOrder( "ASC" );
            $websites = $owebsites->select( $queryOptions );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubHeaderWidget( "Section Creator" );
        $widget->display();

        echo '<form action="index.php" method="post" enctype="multipart/form-data">' . "\n";

        echo '<table border="0" cellspacing="0" cellpadding="5">' . "\n";
        echo '<tr>' . "\n";

        if ( $this->osection->getName() === null ) {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="name" value="' . htmlentities( $this->osection->getName() ) . '" /> <span class="error">&laquo; required field</span></td>' . "\n";
        }
        else {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="' . 30 . '" name="name" value="' . htmlentities( $this->osection->getName() ) . '" /></td>' . "\n";
        }

        echo '</tr>' . "\n";

        $widget = new OnpubWebsitesWidget( $this->osection->getWebsiteID(), $websites, "section" );
        $widget->display();

        if ( sizeof( $websites ) ) {
            echo '<tr>' . "\n";
            echo '<td>' . "\n";
            echo '<input type="checkbox" id="id_public" name="public" value="1" /> <label for="id_public">Add to Website\'s Public Sections</label>' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        if ( $this->osection->getParentID() ) {
            $sectionIDs = array();
            $sectionIDs[] = $this->osection->getParentID();
        }
        else {
            $sectionIDs = null;
        }

        $list = new OnpubSectionsWidget( $sectionIDs, $websites, $osections, array(), "Parent Section", false, "sectionID", null, $this->osection->getParentID() );
        $list->display();

        echo '<tr>' . "\n";
        echo '<td align="left"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'create.gif" border="0" alt="" /></a></td>' . "\n";
        echo '</tr>' . "\n";
        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="SectionCreateProcess" /></div>';

        echo '</form>' . "\n";

        $widget = new OnpubFooterWidget();
        $widget->display();
    }

    public function validate()
    {
        $osections = new OnpubSections( $this->pdo );
        $valid = true;

        if ( $this->osection->getParentID() === "" ) {
            $this->osection->setParentID( null );
        }

        if ( !$this->osection->getName() ) {
            $this->osection->setName( null );
            $valid = false;
        }

        if ( !$this->osection->getWebsiteID() ) {
            $this->osection->setWebsiteID( "" ); // set to empty to signify validation error
            $valid = false;
        }
        else {
            if ( $this->osection->getParentID() ) {
                try {
                    $parent = $osections->get( $this->osection->getParentID() );
                }
                catch ( PDOException $e ) {
                    throw $e;
                }

                if ( $parent->getWebsiteID() != $this->osection->getWebsiteID() ) {
                    $this->osection->setParentID( "" );
                    $valid = false;
                }
            }
        }

        return $valid;
    }

    public function process()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->insert( $this->osection, $this->public );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>