<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubSectionEdit
{
    private $pdo;
    private $osection;

    function __construct( PDO $pdo, OnpubSection $osection )
    {
        $this->pdo = $pdo;
        $this->osection = $osection;
    }

    public function display()
    {
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $oarticles = new OnpubArticles( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $osamaps = new OnpubSAMaps( $this->pdo );

        try {
            $this->osection = $osections->get( $this->osection->getID(), true, false );

            if ( $this->osection->getParentID() ) {
                $parent = $osections->get( $this->osection->getParentID() );
            }

            $website = $owebsites->get( $this->osection->getWebsiteID(), false );
            $numOfArticles = $oarticles->count();

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "name" );
            $queryOptions->setOrder( "ASC" );
            $websites = $owebsites->select( $queryOptions );

            $joinedWebsites = array();

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "fileName" );
            $queryOptions->setOrder( "ASC" );
            $images = $oimages->select( $queryOptions );

/*
            foreach ( $websites as $site ) {
                $joinedWebsites[] = $owebsites->get( $site->getWebsiteID(), true, false, null, null, null, null, false );
            }
*/
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubHeaderWidget( "Section Editor" );
        $widget->display();

        echo '<form action="index.php" method="post">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";
        echo '<tr>' . "\n";

        if ( $numOfArticles ) {
            echo '<td class="buttons"><a href="javascript:selectAll( articleList ); submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" border="0" alt="" /></a> <a href="javascript:sectionDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" border="0" alt="" /></a></td>' . "\n";
        }
        else {
            echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" border="0" alt="" /></a> <a href="javascript:sectionDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" border="0" alt="" /></a></td>' . "\n";
        }

        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->osection->getID() . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->osection->getCreated()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->osection->getModified()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";

        if ( $this->osection->getName() === null ) {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="" /> <span class="error">&laquo; required field</span></td>' . "\n";
        }
        else {
            echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="' . htmlentities( $this->osection->getName() ) . '" /></td>' . "\n";
        }

        echo '</tr>' . "\n";

        $widget = new OnpubImagesWidget( "Icon", $this->osection->getImageID(), $images, $website );
        $widget->display();

        if ( $this->osection->getParentID() ) {
            echo '<tr>' . "\n";
            echo '<td><b>Parent Section</b><br /><a href="index.php?onpub=SectionEdit&amp;sectionID=' . $parent->getID() . '" title="Edit">' . $parent->getName() . '</a></td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>Parent Section</b><br />None</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '<tr>' . "\n";
        echo '<td><b>Website</b><br /><a href="index.php?onpub=WebsiteEdit&amp;websiteID=' . $website->getID() . '" title="Edit">' . $website->getName() . '</a></td>' . "\n";
        echo '</tr>' . "\n";

        if ( $numOfArticles ) {
            $widget = new OnpubArticlesWidget( $this->pdo, $this->osection );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:moveSelectedOptionUp( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'up.gif" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.gif" border="0" alt="" /><a href="javascript:moveSelectedOptionDown( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'down.gif" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.gif" border="0" alt="" /><a href="javascript:removeSelectedArticle( articleList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'remove.gif" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";
        }
        else {
            echo '<tr>' . "\n";
            echo '<td><b>Articles</b><br />' . "\n";
            echo 'There are 0 articles in the database. Use the <a href="index.php?onpub=ArticleCreate"><strong>Article Creator</strong></a> to create some.' . "\n";
            echo '</td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="SectionEditProcess" /></div>';
        echo '<div><input type="hidden" name="sectionID" value="' . $this->osection->getID() . '" /></div>';

        echo '</form>' . "\n";

        echo '<script type="text/javascript">' . "\n";
        echo '<!--' . "\n";

        if ( $numOfArticles ) {
            echo '// convenience variables for form[0]\'s objects' . "\n";
            if ( sizeof ( $images ) ) {
                echo 'var articleList = document.forms[0].elements[2];' . "\n";
            }
            else {
                echo 'var articleList = document.forms[0].elements[1];' . "\n";
            }
        }

        echo '//-->' . "\n";
        echo '</script>' . "\n";

        $widget = new OnpubFooterWidget();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->osection->getName() ) {
            $this->osection->setName( null );
            return false;
        }

        return true;
    }

    public function process()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->update( $this->osection );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $osections = new OnpubSections( $this->pdo );

        try {
            $osections->delete( $this->osection->getID() );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>