<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubSectionsWidget
{
    private $sectionIDs;
    private $websites;
    private $osections;
    private $samaps;
    private $heading;
    private $multiple;
    private $fieldName;
    private $owebsite;
    private $parentID;
    private $inTable;
    private $size;

    function __construct( $sectionIDs, $websites, $osections, $samaps = array(), $heading = "Sections", $multiple = true, $fieldName = "sectionIDs[]", $owebsite = null, $parentID = null, $inTable = true, $size = "10" )
    {
        $this->sectionIDs = $sectionIDs;
        $this->websites = $websites;
        $this->osections = $osections;
        $this->samaps = $samaps;
        $this->heading = $heading;
        $this->multiple = $multiple;
        $this->fieldName = $fieldName;
        $this->owebsite = $owebsite;
        $this->parentID = $parentID;
        $this->inTable = $inTable;
        $this->size = $size;
    }

    function display()
    {
        $sectionsMap = array();
        $websitesMap = array();
        $areSections = false;

        if ( sizeof( $this->websites ) && !$this->owebsite ) {
            for ( $i = 0; $i < sizeof( $this->websites ); $i++ ) {
                $websiteName = $this->websites[$i]->getName();

                try {
                    $queryOptions = new OnpubQueryOptions();
                    $queryOptions->setOrderBy( "name" );
                    $queryOptions->setOrder( "ASC" );
                    $sections = $this->osections->select( $queryOptions, $this->websites[$i]->getID(), false );
                }
                catch ( PDOException $e ) {
                    throw $e;
                }

                $sectionsMap["$websiteName"] = $sections;

                if ( sizeof( $sections ) ) {
                    $areSections = true;
                }
            }
        }

        if ( sizeof( $this->websites ) && $this->owebsite ) {
            for ( $i = 0; $i < sizeof( $this->websites ); $i++ ) {
                $websiteID = $this->websites[$i]->getID();
                $websitesMap["$websiteID"] = $this->websites[$i];
            }
        }

        if ( $areSections ) {
            if ( $this->inTable ) {
                echo '<tr>' . "\n";
                echo '<td><b>' . $this->heading . '</b><br />' . "\n";
            }
            else {
                echo '<b>' . $this->heading . '</b><br />' . "\n";
            }

            if ( $this->multiple ) {
                echo '<small>Hold Ctrl to select/deselect multiple Sections</small><br />' . "\n";
            }

            if ( $this->multiple ) {
                echo '<select name="' . $this->fieldName . '" multiple="multiple" size="' . $this->size . '">' . "\n";
            }
            else {
                echo '<select name="sectionID" size="1">' . "\n";
                echo '<option value="">None</option>';
            }

            if ( is_array( $this->sectionIDs ) ) {
                for ( $i = 0; $i < sizeof( $this->websites ); $i++ ) {
                    $websiteName = $this->websites[$i]->getName();
                    $sections = $sectionsMap["$websiteName"];

                    for ( $j = 0; $j < sizeof( $sections ); $j++ ) {
                        if ( in_array( $sections[$j]->getID(), $this->sectionIDs ) ) {
                            $this->outputSectionListOptions( $this->websites[$i]->getName(), $sections[$j], true );
                        }
                        else {
                            $this->outputSectionListOptions( $this->websites[$i]->getName(), $sections[$j] );
                        }
                    }
                }
            }
            else {
                if ( sizeof( $this->samaps ) ) {
                    $this->sectionIDs = array();

                    for ( $i = 0; $i < sizeof( $this->samaps ); $i++ ) {
                        $this->sectionIDs[$i] = $this->samaps[$i]->getSectionID();
                    }

                    for ( $i = 0; $i < sizeof( $this->websites ); $i++ ) {
                        $websiteName = $this->websites[$i]->getName();
                        $sections = $sectionsMap["$websiteName"];

                        for ( $j = 0; $j < sizeof( $sections ); $j++ ) {
                            if ( in_array( $sections[$j]->getID(), $this->sectionIDs ) ) {
                                $this->outputSectionListOptions( $this->websites[$i]->getName(), $sections[$j], true );
                            }
                            else {
                                $this->outputSectionListOptions( $this->websites[$i]->getName(), $sections[$j] );
                            }
                        }
                    }
                }
                else {
                    for ( $i = 0; $i < sizeof( $this->websites ); $i++ ) {
                        $websiteName = $this->websites[$i]->getName();
                        $sections = $sectionsMap["$websiteName"];

                        for ( $j = 0; $j < sizeof( $sections ); $j++ ) {
                            $this->outputSectionListOptions( $this->websites[$i]->getName(), $sections[$j] );
                        }
                    }
                }
            }

            if ( $this->parentID === "" ) {
                echo '</select> <span class="error">&laquo; parent section must be in selected website</span>' . "\n";
            }
            else {
                echo '</select>' . "\n";
            }

            if ( $this->inTable ) {
                echo '</td>' . "\n";
                echo '</tr>' . "\n";
            }
        }
        else {
            if ( $this->owebsite ) {
                if ( $this->inTable ) {
                    echo '<tr>' . "\n";
                    echo '<td><b>' . $this->heading . '</b><br />' . "\n";
                }
                else {
                    echo '<b>' . $this->heading . '</b><br />' . "\n";
                }

                echo '<small>Hold Ctrl to select/deselect multiple Sections</small><br />' . "\n";
                echo '<select name="' . $this->fieldName . '" multiple="multiple" size="' . $this->size . '">' . "\n";

                $sections = $this->owebsite->getSections();

                if ( sizeof( $sections ) ) {
                    for ( $i = 0; $i < sizeof( $sections ); $i++ ) {
                        if ( $sections[$i]->getWebsiteID() == $this->owebsite->getID() ) {
                            $this->outputSectionListOptions( $this->owebsite->getName(), $sections[$i], true );
                        }
                        else {
                            $websiteID = $sections[$i]->getWebsiteID();
                            $website = $websitesMap["$websiteID"];
                            $this->outputSectionListOptions( $website->getName(), $sections[$i], true );
                        }
                    }
                }
                else {
                    echo '<option value="" selected="selected">None</option>';
                }

                echo '</select>' . "\n";

                if ( $this->inTable ) {
                    echo '</td>' . "\n";
                    echo '</tr>' . "\n";
                }
            }
            else {
                if ( $this->heading != "Parent Section" ) {
/*
                    echo '<tr>' . "\n";
                    echo '<td><b>' . $this->heading . '</b><br />' . "\n";

                    echo 'There are 0 sections in the database. Use the <a href="index.php?onpub=SectionCreate"><strong>Section Creator</strong></a> to create some.' . "\n";

                    echo '</td>' . "\n";
                    echo '</tr>' . "\n";
*/
                }
            }
        }
    }

    private function outputSectionListOptions( $websiteName, $section, $selected = false ) {
        $sections = $section->getSections();

        if ( !$section->getParentID() ) {
            if ( $selected ) {
                echo '<option value="' . $section->getID() . '" selected="selected">' . strip_tags( $websiteName ) . ' &ndash; ' . strip_tags( $section->getName() ) . '</option>' . "\n";
            }
            else {
                echo '<option value="' . $section->getID() . '">' . strip_tags( $websiteName ) . ' &ndash; ' . strip_tags( $section->getName() ) . '</option>' . "\n";
            }
        }

        for ( $i = 0; $i < sizeof( $sections ); $i++ ) {
            $section = $sections[$i];
            $wN = $websiteName;
            $sectionName = strip_tags( $wN );
            $sectionNames = array();

            $sectionNames[] = $section->getName();

            if ( $section->getParentID() ) {
                $parent = $section->getParent();
                $sectionNames[] = $parent->getName();

                while ( $parent->getParentID() ) {
                    $parent = $parent->getParent();
                    $sectionNames[] = $parent->getName();
                }
            }

            $sectionNames = array_reverse( $sectionNames );

            foreach ( $sectionNames as $sN ) {
                $sectionName  .= ' &ndash; ' . $sN;
            }

            echo '<option value="' . $section->getID() . '">' . strip_tags( $sectionName ) . '</option>' . "\n";

            $this->outputSectionListOptions( $wN, $section );
        }
    }
}

?>
