<?php

/**
 * @author {@link mailto:corey@onpubco.com Corey HM Taylor}
 * @copyright Onpub (TM) Copyright (C) 2007, Onpubco
 * {@link http://onpubco.com/}
 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * Version 2
 * @package onpubgui
 * @version 0.8.3
 */
class OnpubWebsiteEdit
{
    private $pdo;
    private $owebsite;
    private $sectionIDs;

    function __construct( PDO $pdo, $owebsite, $sectionIDs = null )
    {
        $this->pdo = $pdo;
        $this->owebsite = $owebsite;
        $this->sectionIDs = $sectionIDs;
    }

    public function display()
    {
        $osections = new OnpubSections( $this->pdo );
        $owebsites = new OnpubWebsites( $this->pdo );
        $oimages = new OnpubImages( $this->pdo );
        $owsmaps = new OnpubWSMaps( $this->pdo );

        try {
            $totalSections = $osections->count();
            $date = new OnpubDateTime();
            $this->owebsite = $owebsites->get( $this->owebsite->getID(), true, false, null, null, null, null, true, false );
            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "name" );
            $queryOptions->setOrder( "ASC" );
            $websites = $owebsites->select( $queryOptions );

            $queryOptions = new OnpubQueryOptions();
            $queryOptions->setOrderBy( "fileName" );
            $queryOptions->setOrder( "ASC" );
            $images = $oimages->select( $queryOptions );
        }
        catch ( PDOException $e ) {
            throw $e;
        }

        $widget = new OnpubHeaderWidget( "Website Editor" );
        $widget->display();

        echo '<form action="index.php" method="post" enctype="multipart/form-data">' . "\n";

        echo '<table border="0" cellpadding="5" cellspacing="0">' . "\n";
        echo '<tr>' . "\n";

        if ( $totalSections ) {
            echo '<td class="buttons"><a href="javascript:selectAll( sectionList ); submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" border="0" alt="" /></a> <a href="javascript:websiteDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" border="0" alt="" /></a></td>' . "\n";
        }
        else {
            echo '<td class="buttons"><a href="javascript:submitForm();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'save.gif" border="0" alt="" /></a> <a href="javascript:websiteDelete();"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'delete.gif" border="0" alt="" /></a></td>' . "\n";
        }

        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>ID</b><br />' . $this->owebsite->getID() . '</td>' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Created</b><br />' . $this->owebsite->getCreated()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Modified</b><br />' . $this->owebsite->getModified()->getTextualDateTime() . '' . "\n";
        echo '</tr>' . "\n";

        echo '<tr>' . "\n";
        echo '<td><b>Name</b><br /><input type="text" maxlength="255" size="75" name="name" value="' . htmlentities( $this->owebsite->getName() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        echo '<tr>' . "\n";
        echo '<td><b>URL</b>' . $message . '<br /><input type="text" maxlength="255" size="75" name="url" value="' . htmlentities( $this->owebsite->getURL() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        if ( file_exists( $this->owebsite->getImagesDirectory() ) ) {
            if ( !is_writable( $this->owebsite->getImagesDirectory() ) ) {
                $message = '&laquo; directory is not writable';
            }
        }
        else {
            if ( $this->owebsite->getImagesDirectory() ) {
                $message = '&laquo; directory does not exist on <i>' . $_SERVER["SERVER_NAME"] . '</i>';
            }
        }

        echo '<tr>' . "\n";
        echo '<td><b>Images Directory</b><br /><small>Images uploaded to this website will be saved to this directory on <i>' . $_SERVER["SERVER_NAME"] . '</i></small><br /><input type="text" maxlength="255" size="75" name="imagesDirectory" value="' . htmlentities( $this->owebsite->getImagesDirectory() ) . '" /> <span class="error">' . $message . '</span></td>' . "\n";
        echo '</tr>' . "\n";

        $message = "";

        if ( $this->owebsite->getImagesURL() ) {
            $message = '<br /><small>Images uploaded to this website should be accessible from this URL</small>';
        }
        else {
            $message = '<br /><small>Should be a URL to the Images Directory, example: http://onpubco.com/images/</small>';
        }

        echo '<tr>' . "\n";
        echo '<td><b>Images URL</b>' . $message . '<br /><input type="text" maxlength="255" size="75" name="imagesURL" value="' . htmlentities( $this->owebsite->getImagesURL() ) . '" /></td>' . "\n";
        echo '</tr>' . "\n";

        $widget = new OnpubImagesWidget( "Logo", $this->owebsite->getImageID(), $images, $this->owebsite );
        $widget->display();

        if ( $totalSections ) {
            $widget = new OnpubSectionsWidget( null, $websites, $osections, array(), "All Sections", true, "existingSections" );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:addExistingSection( existingSections, sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'add.gif" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";

            $widget = new OnpubSectionsWidget( $this->sectionIDs, $websites, $osections, array(), "Public Sections", true, "sectionIDs[]", $this->owebsite );
            $widget->display();

            echo '<tr>' . "\n";
            echo '<td><a href="javascript:moveSelectedOptionUp( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'up.gif" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.gif" border="0" alt="" /><a href="javascript:moveSelectedOptionDown( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'down.gif" border="0" alt="" /></a><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'buttonspacer.gif" border="0" alt="" /><a href="javascript:removeSelectedSection( sectionList );"><img src="' . ONPUBGUI_IMAGE_DIRECTORY . 'remove.gif" border="0" alt="" /></a></td>' . "\n";
            echo '</tr>' . "\n";
        }

        echo '</table>' . "\n";

        echo '<div><input type="hidden" name="onpub" value="WebsiteEditProcess" /></div>';
        echo '<div><input type="hidden" name="websiteID" value="' . $this->owebsite->getID() . '" /></div>';

        echo '</form>' . "\n";

        echo '<script type="text/javascript">' . "\n";
        echo '<!--' . "\n";

        echo "\n" . '// convenience variables for form[0]\'s objects' . "\n";
        echo 'var existingSections = document.forms[0].existingSections;' . "\n";

        if ( sizeof( $images ) ) {
            echo 'var sectionList = document.forms[0].elements[6];' . "\n";
        }
        else {
            echo 'var sectionList = document.forms[0].elements[5];' . "\n";
        }

        echo '//-->' . "\n";
        echo '</script>' . "\n";

        $widget = new OnpubFooterWidget();
        $widget->display();
    }

    public function validate()
    {
        if ( !$this->owebsite->getName() ) {
            $this->owebsite->setName( null );
            return false;
        }

        return true;
    }

    public function process()
    {
        $owebsites = new OnpubWebsites( $this->pdo );

        $sections = array();

        for ( $i = 0; $i < sizeof( $this->sectionIDs ); $i++ ) {
            if ( $this->sectionIDs[$i] ) {
                $section = new OnpubSection();

                $section->setID( $this->sectionIDs[$i] );
                $section->setWebsiteID( $this->owebsite->getID() );

                $sections[] = $section;
            }
        }

        $this->owebsite->setSections( $sections );

        try {
            $owebsites->update( $this->owebsite );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }

    public function delete()
    {
        $owebsites = new OnpubWebsites( $this->pdo );

        try {
            $owebsites->delete( $this->owebsite->getID() );
        }
        catch ( PDOException $e ) {
            throw $e;
        }
    }
}

?>