<?php

/* Onpub (TM)
 * Copyright (C) 2007 Onpubco <http://onpubco.com/>
 * Author: Corey HM Taylor <corey@onpubco.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; version 2.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

header( "Content-Type: text/html; charset=iso-8859-1" );

include( "api/onpubapi.php" );
include( "gui/onpubgui.php" );

if ( defined( "ONPUBGUI_SQLITE_DB_FILE" ) ) {
    session_name( "onpubsqlite" );
}
else {
    session_name( "onpubpdo" );
}

session_set_cookie_params( 2678400 );
session_start();

$pdo = null;
$loginStatus = false;
$dsn = "";
$username = "";
$password = "";

if ( defined( "ONPUBGUI_SQLITE_DB_FILE" ) ) {
    $loginStatus = true;
    $dsn = "sqlite:" . ONPUBGUI_SQLITE_DB_FILE;
    $_SESSION["ONPUBAPI_PDO_HOST"] = null;
    $_SESSION["ONPUBAPI_PDO_USER"] = null;
    $_SESSION["ONPUBAPI_PDO_PASSWORD"] = null;
    $_SESSION["ONPUBAPI_PDO_DATABASE"] = ONPUBGUI_SQLITE_DB_FILE;
}
else {
    if ( isset( $_SESSION["ONPUBAPI_PDO_HOST"] ) && isset( $_SESSION["ONPUBAPI_PDO_USER"] ) && isset( $_SESSION["ONPUBAPI_PDO_PASSWORD"] ) && isset( $_SESSION["ONPUBAPI_PDO_DATABASE"] ) ) {
        $loginStatus = true;
        $dsn = "mysql:host=" . $_SESSION['ONPUBAPI_PDO_HOST'] . ";dbname=" . $_SESSION['ONPUBAPI_PDO_DATABASE'];
        $username = $_SESSION['ONPUBAPI_PDO_USER'];
        $password = $_SESSION['ONPUBAPI_PDO_PASSWORD'];
    }
}

if ( isset( $_POST["onpub"] ) ) {
    if ( !$loginStatus && $_POST["onpub"] != "LoginProcess" ) {
        header( "Location: index.php" );
        exit;
    }

    switch ( $_POST["onpub"] ) {
        case "LoginProcess":
            if ( isset( $_POST["rememberLogin"] ) ) {
                $rememberLogin = true;
            }
            else {
                $rememberLogin = false;
            }

            if ( isset( $_POST["target"] ) ) {
                if ( $_POST["target"] == "Logout" ) {
                    $logout = true;
                    $target = null;
                }
                else {
                    $logout = false;
                    $target = $_POST["target"];
                }
            }
            else {
                $logout = false;
                $target = null;
            }

            $login = new OnpubLogin( $_POST["pdoDatabase"], $_POST["pdolUser"], $_POST["pdoPassword"], $logout, $target, $rememberLogin );

            try {
                if ( !$login->validate() ) {
                    $login->display();
                    return;
                }
            }
            catch ( PDOException $e ) {
                $login->setException( $e );
                $login->display();
                return;
            }

            $login->process();

            if ( $login->getTarget() ) {
                header( "Location: index.php?" . $login->getTarget() );
                exit;
            }
            else {
                header( "Location: index.php" );
                exit;
            }
        break;

        case "ImageEditProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $oimage = new OnpubImage();
            $oimage->setID( $_POST["imageID"] );
            $oimage->setFileName( $_POST["fileName"] );
            $oimage->setDescription( $_POST["description"] );

            $edit = new OnpubImageEdit( $pdo, $oimage, $_POST["oldImageFileName"] );

            if ( !$edit->validate() ) {
                $edit->display();
                return;
            }

            try {
                $edit->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ImageEdit&imageID=" . $_POST["imageID"] );
            exit;
        break;

        case "ArticleCreateProcess":
            if ( isset( $_POST["sectionIDs"] ) ) {
                $sectionIDs = $_POST["sectionIDs"];
                $_SESSION["ONPUBGUI_AC_SIDS"] = $sectionIDs;
            }
            else {
                $sectionIDs = array();
                $_SESSION["ONPUBGUI_AC_SIDS"] = $sectionIDs;
            }

            if ( isset( $_POST["displayAs"] ) ) {
                $displayAs = $_POST["displayAs"];
                $_SESSION["ONPUBGUI_AC_DA"] = $displayAs;
            }
            else {
                $displayAs = "";
            }

            if ( isset( $_POST["imageID"] ) ) {
                $imageID = $_POST["imageID"];
                $_SESSION["ONPUBGUI_AC_IID"] = $imageID;

                if ( !$imageID ) {
                    $imageID = null;
                }
            }
            else {
                $imageID = null;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $odate = new OnpubDateTime();
            $odate->setYear( $_POST["createdYear"] );
            $odate->setMonth( $_POST["createdMonth"] );
            $odate->setDay( $_POST["createdDay"] );
            $odate->setHour( $_POST["createdHour"] );
            $odate->setMinute( $_POST["createdMinute"] );
            $odate->setSecond( $_POST["createdSecond"] );

            $oarticle = new OnpubArticle();
            $oarticle->setImageID( $imageID );
            $oarticle->setTitle( $_POST["title"] );
            $oarticle->setContent( stripslashes( $_POST["content"] ) );
            $oarticle->setURL( $_POST["url"] );
            $oarticle->setCreated( $odate );
            $oarticle->setSectionIDs( $sectionIDs );

            $oauthor = new OnpubAuthor();
            $oauthor->setDisplayAs( $displayAs );

            $tidyConfig = OnpubTidy::getDefaultOptions();

            if ( isset( $_POST["markup"] ) ) {
                $tidyConfig["markup"] = $_POST["markup"];
                $_SESSION["ONPUBGUI_AC_M"] = $_POST["markup"];
            }
            else {
                $tidyConfig["markup"] = false;
                $_SESSION["ONPUBGUI_AC_M"] = false;
            }

            if ( isset( $_POST["nltobr"] ) ) {
                $nltobr = $_POST["nltobr"];
            }
            else {
                $nltobr = "0";
            }

            if ( isset( $_POST["delbr"] ) ) {
                $delbr = $_POST["delbr"];
            }
            else {
                $delbr = "0";
            }

            $create = new OnpubArticleCreate( $pdo, $oarticle, $oauthor, $tidyConfig, $nltobr, $delbr );

            if ( !$create->validate() ) {
                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $create->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ArticleEdit&ID=" . $oarticle->getID() );
            exit;
        break;

        case "ArticleEditProcess":
            if ( isset( $_POST["authorID"] ) ) {
                $authorID = $_POST["authorID"];
            }
            else {
                $authorID = null;
            }

            if ( isset( $_POST["sectionIDs"] ) ) {
                $sectionIDs = $_POST["sectionIDs"];
            }
            else {
                $sectionIDs = null;
            }

            if ( isset( $_POST["displayAs"] ) ) {
                $displayAs = $_POST["displayAs"];
            }
            else {
                $displayAs = "";
            }

            if ( isset( $_POST["imageID"] ) ) {
                $imageID = $_POST["imageID"];

                if ( !$imageID ) {
                    $imageID = null;
                }
            }
            else {
                $imageID = null;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $odate = new OnpubDateTime();
            $odate->setYear( $_POST["createdYear"] );
            $odate->setMonth( $_POST["createdMonth"] );
            $odate->setDay( $_POST["createdDay"] );
            $odate->setHour( $_POST["createdHour"] );
            $odate->setMinute( $_POST["createdMinute"] );
            $odate->setSecond( $_POST["createdSecond"] );

            $oarticle = new OnpubArticle();
            $oarticle->setID( $_POST["ID"] );
            $oarticle->setImageID( $imageID );
            $oarticle->setTitle( $_POST["title"] );
            $oarticle->setContent( stripslashes( $_POST["content"] ) );
            $oarticle->setURL( $_POST["url"] );
            $oarticle->setCreated( $odate );
            $oarticle->setSectionIDs( $sectionIDs );

            if ( $displayAs !== "" ) {
                $oauthor = new OnpubAuthor();

                if ( $displayAs == $_POST["lastDisplayAs"] ) {
                    $oauthor->setID( $authorID );
                }

                if ( $_POST["authorImageID"] ) {
                    $oauthor->setImageID( $_POST["authorImageID"] );
                }

                $oauthor->setDisplayAs( $displayAs );
                $oarticle->setAuthors( array( $oauthor ) );
            }

            $tidyConfig = OnpubTidy::getDefaultOptions();

            if ( isset( $_POST["markup"] ) ) {
                $tidyConfig["markup"] = $_POST["markup"];
                $_SESSION["ONPUBGUI_AE_M"] = $_POST["markup"];
            }
            else {
                $tidyConfig["markup"] = false;
                $_SESSION["ONPUBGUI_AE_M"] = false;
            }

            if ( isset( $_POST["nltobr"] ) ) {
                $nltobr = $_POST["nltobr"];
            }
            else {
                $nltobr = "0";
            }

            if ( isset( $_POST["delbr"] ) ) {
                $delbr = $_POST["delbr"];
            }
            else {
                $delbr = "0";
            }

            $edit = new OnpubArticleEdit( $pdo, $oarticle, $tidyConfig, $nltobr, $delbr );

            if ( !$edit->validate() ) {
                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $edit->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ArticleEdit&ID=" . $_POST["ID"] );
            exit;
        break;

        case "ImageUploadProcess":
            if ( isset( $_POST["websiteID"] ) ) {
                $websiteID = $_POST["websiteID"];
            }
            else {
                $websiteID = null;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
            $upload = new OnpubImageUpload( $pdo, $_FILES["imageFile"]["tmp_name"], $_FILES["imageFile"]["name"], $websiteID );

            if ( !$upload->validate() ) {
                try {
                    $upload->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $upload->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }
            catch ( Exception $e ) {
                try {
                    $upload->displayException( $e );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ImageEdit&imageID=" . $upload->getImageID() );
            exit;
        break;

        case "ImageDeleteProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $oimage = new OnpubImage();
            $oimage->setID( $_POST["imageID"] );

            $edit = new OnpubImageEdit( $pdo, $oimage, $_POST["oldImageFileName"] );

            try {
                $edit->delete();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ImageSelect" );
            exit;
        break;

        case "SectionDeleteProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $osection = new OnpubSection();
            $osection->setID( $_POST["sectionID"] );

            $edit = new OnpubSectionEdit( $pdo, $osection );

            try {
                $edit->delete();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=SectionSelect" );
            exit;
        break;

        case "WebsiteDeleteProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $owebsite = new OnpubWebsite();
            $owebsite->setID( $_POST["websiteID"] );

            $edit = new OnpubWebsiteEdit( $pdo, $owebsite );

            try {
                $edit->delete();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=WebsiteSelect" );
            exit;
        break;

        case "ArticleDeleteProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            if ( isset( $_POST["IDs"] ) ) {
                $IDs = $_POST["IDs"];
            }
            else {
                $IDs = array();
            }

            $delete = new OnpubArticleDelete( $pdo, $IDs );

            try {
                $delete->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ArticleSelect" );
            exit;
        break;

        case "ArticleMoveProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            if ( isset( $_POST["IDs"] ) ) {
                $IDs = $_POST["IDs"];
            }
            else {
                $IDs = array();
            }

            if ( isset( $_POST["sectionIDs"] ) ) {
                $sectionIDs = $_POST["sectionIDs"];
            }
            else {
                $sectionIDs = array();
            }

            $move = new OnpubArticleMove( $pdo, $IDs, $sectionIDs );

            try {
                $move->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=ArticleSelect" );
            exit;
        break;

        case "WebsiteCreateProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $owebsite = new OnpubWebsite();

            $owebsite->setName( $_POST["name"] );

            $create = new OnpubWebsiteCreate( $pdo, $owebsite );

            if ( !$create->validate() ) {
                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $create->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=WebsiteEdit&websiteID=" . $owebsite->getID() );
            exit;
        break;

        case "SectionCreateProcess":
            if ( isset( $_POST["websiteID"] ) ) {
                $websiteID = $_POST["websiteID"];
            }
            else {
                $websiteID = null;
            }

            if ( isset( $_POST["sectionID"] ) ) {
                $parentID = $_POST["sectionID"];
            }
            else {
                $parentID = null;
            }

            if ( isset( $_POST["public"] ) ) {
                $public = true;
            }
            else {
                $public = false;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $osection = new OnpubSection();
            $osection->setWebsiteID( $websiteID );
            $osection->setParentID( $parentID );
            $osection->setName( $_POST["name"] );

            $create = new OnpubSectionCreate( $pdo, $osection, $public );

            if ( !$create->validate() ) {
                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $create->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=SectionEdit&sectionID=" . $osection->getID() );
            exit;
        break;

        case "SectionEditProcess":
            if ( isset( $_POST["IDs"] ) ) {
                $IDs = $_POST["IDs"];
            }
            else {
                $IDs = array();
            }

            if ( isset( $_POST["imageID"] ) ) {
                $imageID = $_POST["imageID"];

                if ( !$imageID ) {
                    $imageID = null;
                }
            }
            else {
                $imageID = null;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $oarticles = array();

            foreach ( $IDs as $aID ) {
                if ( $aID ) {
                    $oarticle = new OnpubArticle();
                    $oarticle->setID( $aID );
                    $oarticles[] = $oarticle;
                }
            }

            $osection = new OnpubSection();
            $osection->setID( $_POST["sectionID"] );
            $osection->setImageID( $imageID );
            $osection->setName( $_POST["name"] );
            $osection->setArticles( $oarticles );

            $edit = new OnpubSectionEdit( $pdo, $osection );

            if ( !$edit->validate() ) {
                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $edit->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=SectionEdit&sectionID=" . $osection->getID() );
            exit;
        break;

        case "DataRestoreProcess":
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
            $upload = new OnpubDataRestore( $pdo, $_FILES["tablesFile"]["tmp_name"], $_FILES["tablesFile"]["name"] );

            if ( !$upload->validate() ) {
                try {
                    $upload->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $upload->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }
            catch ( Exception $e ) {
                try {
                    $upload->displayException( $e );
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php" );
            exit;
        break;

        case "WebsiteEditProcess":
            if ( isset( $_POST["sectionIDs"] ) ) {
                $sectionIDs = $_POST["sectionIDs"];
            }
            else {
                $sectionIDs = null;
            }

            if ( isset( $_POST["imageID"] ) ) {
                $imageID = $_POST["imageID"];

                if ( !$imageID ) {
                    $imageID = null;
                }
            }
            else {
                $imageID = null;
            }

            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

            $owebsite = new OnpubWebsite();
            $owebsite->setID( $_POST["websiteID"] );
            $owebsite->setImageID( $imageID );
            $owebsite->setName( $_POST["name"] );
            $owebsite->setURL( $_POST["url"] );
            $owebsite->setImagesURL( $_POST["imagesURL"] );
            $owebsite->setImagesDirectory( $_POST["imagesDirectory"] );

            $edit = new OnpubWebsiteEdit( $pdo, $owebsite, $sectionIDs );

            if ( !$edit->validate() ) {
                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                return;
            }

            try {
                $edit->process();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;

            header( "Location: index.php?onpub=WebsiteEdit&websiteID=" . $_POST["websiteID"] );
            exit;
        break;
    }
}
else {
    if ( isset( $_GET["onpub"] ) ) {
        if ( !$loginStatus ) {
            $login = new OnpubLogin( null, null, null, false, $_GET );
            $login->display();
            return;
        }

        switch ( $_GET["onpub"] ) {
            case "Logout":
                $login = new OnpubLogin( "", "", "", true );
                $login->process();

                header( "Location: index.php" );
                exit;
            break;

            case "DataBackup":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $odatabase = new OnpubDatabase( $pdo );

                try {
                    $tempname = $odatabase->backup();

                    if ( $tempname ) {
                        $filename = str_replace( '/tmp/', '', $tempname );
                        header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
                        header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
                        header("Content-type: application/x-download");
                        header("Content-Disposition: attachment; filename={$filename}");
                        header("Content-Transfer-Encoding: binary");
                        header('Content-Length: '.filesize($tempname));
                        readfile( $tempname );
                        unlink( $tempname );
                        exit;
                    }
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "DataDelete":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $odatabase = new OnpubDatabase( $pdo );

                try {
                    $odatabase->delete();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
                header( "Location: index.php" );
                exit;
            break;

            case "SchemaInstall":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $odatabase = new OnpubDatabase( $pdo );

                try {
                    $odatabase->install();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
                header( "Location: index.php" );
                exit;
            break;

            case "ArticleCreate":
                if ( isset( $_SESSION["ONPUBGUI_AC_DA"] ) ) {
                    $displayAs = $_SESSION["ONPUBGUI_AC_DA"];
                }
                else {
                    $displayAs = "";
                }

                if ( isset( $_SESSION["ONPUBGUI_AC_SIDS"] ) ) {
                    $sectionIDs = $_SESSION["ONPUBGUI_AC_SIDS"];
                }
                else {
                    $sectionIDs = array();
                }

                if ( isset( $_SESSION["ONPUBGUI_AC_IID"] ) ) {
                    $imageID = $_SESSION["ONPUBGUI_AC_IID"];
                }
                else {
                    $imageID = null;
                }

                $tidyOptions = OnpubTidy::getDefaultOptions();

                if ( isset( $_SESSION["ONPUBGUI_AC_M"] ) ) {
                    $tidyOptions["markup"] = $_SESSION["ONPUBGUI_AC_M"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $oarticle = new OnpubArticle();
                $oarticle->setImageID( $imageID );
                $oarticle->setSectionIDs( $sectionIDs );

                $oauthor = new OnpubAuthor();
                $oauthor->setDisplayAs( $displayAs );

                $create = new OnpubArticleCreate( $pdo, $oarticle, $oauthor, $tidyOptions );

                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ArticleDelete":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $IDs = array();

                if ( isset( $_GET["ID"] ) ) {
                    $IDs[] = $_GET["ID"];
                }
                elseif ( isset( $_GET["IDs"] ) ) {
                    $IDs = $_GET["IDs"];
                }

                $delete = new OnpubArticleDelete( $pdo, $IDs );

                try {
                    $delete->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ArticleEdit":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $oarticle = new OnpubArticle();
                $oarticle->setID( $_GET["ID"] );

                $tidyOptions = OnpubTidy::getDefaultOptions();

                if ( isset( $_SESSION["ONPUBGUI_AE_M"] ) ) {
                    $tidyOptions["markup"] = $_SESSION["ONPUBGUI_AE_M"];
                }

                $edit = new OnpubArticleEdit( $pdo, $oarticle, $tidyOptions );

                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ArticleMove":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $IDs = array();

                if ( isset( $_GET["ID"] ) ) {
                    $IDs[] = $_GET["ID"];
                }
                elseif ( isset( $_GET["IDs"] ) ) {
                    $IDs = $_GET["IDs"];
                }

                $move = new OnpubArticleMove( $pdo, $IDs );

                try {
                    $move->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ArticleSelect":
                if ( isset( $_GET["orderBy"] ) && isset( $_GET["order"] ) ) {
                    $orderBy = $_GET["orderBy"];
                    $order = $_GET["order"];
                    $_SESSION["ONPUBGUI_AS_OB"] = $orderBy;
                    $_SESSION["ONPUBGUI_AS_O"] = $order;
                }
                else {
                    $orderBy = null;
                    $order = null;
                }

                if ( isset( $_GET["page"] ) ) {
                    $page = $_GET["page"];
                    $_SESSION["ONPUBGUI_AS_P"] = $page;
                }
                else {
                    $page = null;
                }

                if ( isset( $_GET["keywords"] ) ) {
                    $keywords = $_GET["keywords"];

                    if ( isset( $_SESSION["ONPUBGUI_AS_S"] ) ) {
                        if ( $_GET["keywords"] != $_SESSION["ONPUBGUI_AS_S"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_AS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_AS_S"] = $keywords;
                }
                else {
                    $keywords = null;
                }

                if ( isset( $_GET["fullTextSearch"] ) ) {
                    $fullTextSearch = $_GET["fullTextSearch"];

                    $_SESSION["ONPUBGUI_AS_F"] = $fullTextSearch;
                }
                else {
                    $fullTextSearch = null;
                    $_SESSION["ONPUBGUI_AS_F"] = $fullTextSearch;
                }

                if ( isset( $_GET["sectionID"] ) ) {

                    $sectionID = $_GET["sectionID"];

                    if ( isset( $_SESSION["ONPUBGUI_AS_SID"] ) ) {
                        if ( $_GET["sectionID"] != $_SESSION["ONPUBGUI_AS_SID"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_AS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_AS_SID"] = $sectionID;
                }
                else {
                    $sectionID = null;
                }

                if ( isset( $_SESSION["ONPUBGUI_AS_OB"] ) && isset( $_SESSION["ONPUBGUI_AS_O"] ) ) {
                    $orderBy = $_SESSION["ONPUBGUI_AS_OB"];
                    $order = $_SESSION["ONPUBGUI_AS_O"];
                }

                if ( isset( $_SESSION["ONPUBGUI_AS_P"] ) ) {
                    $page = $_SESSION["ONPUBGUI_AS_P"];
                }

                if ( isset( $_SESSION["ONPUBGUI_AS_S"] ) ) {
                    $keywords = $_SESSION["ONPUBGUI_AS_S"];
                }

                if ( isset( $_SESSION["ONPUBGUI_AS_F"] ) ) {
                    $fullTextSearch = $_SESSION["ONPUBGUI_AS_F"];
                }

                if ( isset( $_SESSION["ONPUBGUI_AS_SID"] ) ) {
                    $sectionID = $_SESSION["ONPUBGUI_AS_SID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $select = new OnpubArticleSelect( $pdo, $orderBy, $order, $page, $keywords, $fullTextSearch, $sectionID );

                try {
                    $select->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ArticleView":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                if ( isset( $_GET["articleID"] ) ) {
                    $articleID = $_GET["articleID"];
                }
                else {
                    $articleID = $_GET["ID"];
                }

                $view = new OnpubArticleView( $pdo, $articleID );

                try {
                    $view->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ImageEdit":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                if ( isset( $_GET["imageID"] ) ) {
                    $imageID = $_GET["imageID"];
                }
                else {
                    $imageID = $_GET["ID"];
                }

                $oimage = new OnpubImage();
                $oimage->setID( $imageID );

                $edit = new OnpubImageEdit( $pdo, $oimage );
                $edit->display();

                $pdo = null;
            break;

            case "ImageSelect":
                if ( isset( $_GET["orderBy"] ) && isset( $_GET["order"] ) ) {
                    $orderBy = $_GET["orderBy"];
                    $order = $_GET["order"];
                    $_SESSION["ONPUBGUI_IS_OB"] = $orderBy;
                    $_SESSION["ONPUBGUI_IS_O"] = $order;
                }
                else {
                    $orderBy = null;
                    $order = null;
                }

                if ( isset( $_GET["page"] ) ) {
                    $page = $_GET["page"];
                    $_SESSION["ONPUBGUI_IS_P"] = $page;
                }
                else {
                    $page = null;
                }

                if ( isset( $_GET["keywords"] ) ) {
                    $keywords = $_GET["keywords"];

                    if ( isset( $_SESSION["ONPUBGUI_IS_S"] ) ) {
                        if ( $_GET["keywords"] != $_SESSION["ONPUBGUI_IS_S"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_IS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_IS_S"] = $keywords;
                }
                else {
                    $keywords = null;
                }

                if ( isset( $_GET["fullTextSearch"] ) ) {
                    $fullTextSearch = $_GET["fullTextSearch"];
                    $_SESSION["ONPUBGUI_IS_F"] = $fullTextSearch;
                }
                else {
                    $fullTextSearch = null;
                    $_SESSION["ONPUBGUI_IS_F"] = $fullTextSearch;
                }

                if ( isset( $_GET["sectionID"] ) ) {
                    $sectionID = $_GET["sectionID"];

                    if ( isset( $_SESSION["ONPUBGUI_IS_SID"] ) ) {
                        if ( $_GET["sectionID"] != $_SESSION["ONPUBGUI_IS_SID"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_IS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_IS_SID"] = $sectionID;
                }
                else {
                    $sectionID = null;
                }

                if ( isset( $_SESSION["ONPUBGUI_IS_OB"] ) && isset( $_SESSION["ONPUBGUI_IS_O"] ) ) {
                    $orderBy = $_SESSION["ONPUBGUI_IS_OB"];
                    $order = $_SESSION["ONPUBGUI_IS_O"];
                }

                if ( isset( $_SESSION["ONPUBGUI_IS_P"] ) ) {
                    $page = $_SESSION["ONPUBGUI_IS_P"];
                }

                if ( isset( $_SESSION["ONPUBGUI_IS_S"] ) ) {
                    $keywords = $_SESSION["ONPUBGUI_IS_S"];
                }

                if ( isset( $_SESSION["ONPUBGUI_IS_F"] ) ) {
                    $fullTextSearch = $_SESSION["ONPUBGUI_IS_F"];
                }

                if ( isset( $_SESSION["ONPUBGUI_IS_SID"] ) ) {
                    $sectionID = $_SESSION["ONPUBGUI_IS_SID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $select = new OnpubImageSelect( $pdo, $orderBy, $order, $page, $keywords, $fullTextSearch, $sectionID );

                try {
                    $select->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ImageUpload":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $upload = new OnpubImageUpload( $pdo );

                try {
                    $upload->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "ImageDeleteProcess":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $oimage = new OnpubImage();
                $oimage->setID( $_GET["imageID"] );

                $edit = new OnpubImageEdit( $pdo, $_GET["imageID"], $_GET["fileName"] );

                try {
                    $edit->delete();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;

                header( "Location: index.php?onpub=ImageSelect" );
                exit;
            break;

            case "SectionEdit":
                if ( isset( $_GET["sectionID"] ) ) {
                    $sectionID = $_GET["sectionID"];
                }
                else {
                    $sectionID = $_GET["ID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $osection = new OnpubSection();
                $osection->setID( $sectionID );

                $edit = new OnpubSectionEdit( $pdo, $osection );

                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "SectionCreate":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $osection = new OnpubSection();

                $create = new OnpubSectionCreate( $pdo, $osection );

                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "SectionSelect":
                if ( isset( $_GET["orderBy"] ) && isset( $_GET["order"] ) ) {
                    $orderBy = $_GET["orderBy"];
                    $order = $_GET["order"];
                    $_SESSION["ONPUBGUI_SS_OB"] = $orderBy;
                    $_SESSION["ONPUBGUI_SS_O"] = $order;
                }
                else {
                    $orderBy = null;
                    $order = null;
                }

                if ( isset( $_GET["page"] ) ) {
                    $page = $_GET["page"];
                    $_SESSION["ONPUBGUI_SS_P"] = $page;
                }
                else {
                    $page = null;
                }

                if ( isset( $_GET["keywords"] ) ) {
                    $keywords = $_GET["keywords"];

                    if ( isset( $_SESSION["ONPUBGUI_SS_S"] ) ) {
                        if ( $_GET["keywords"] != $_SESSION["ONPUBGUI_SS_S"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_SS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_SS_S"] = $keywords;
                }
                else {
                    $keywords = null;
                }

                if ( isset( $_GET["fullTextSearch"] ) ) {
                    $fullTextSearch = $_GET["fullTextSearch"];
                    $_SESSION["ONPUBGUI_SS_F"] = $fullTextSearch;
                }
                else {
                    $fullTextSearch = null;
                    $_SESSION["ONPUBGUI_SS_F"] = $fullTextSearch;
                }

                if ( isset( $_GET["websiteID"] ) ) {
                    $websiteID = $_GET["websiteID"];

                    if ( isset( $_SESSION["ONPUBGUI_SS_WID"] ) ) {
                        if ( $_GET["websiteID"] != $_SESSION["ONPUBGUI_SS_WID"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_SS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_SS_WID"] = $websiteID;
                }
                else {
                    $websiteID = null;
                }

                if ( isset( $_SESSION["ONPUBGUI_SS_OB"] ) && isset( $_SESSION["ONPUBGUI_SS_O"] ) ) {
                    $orderBy = $_SESSION["ONPUBGUI_SS_OB"];
                    $order = $_SESSION["ONPUBGUI_SS_O"];
                }

                if ( isset( $_SESSION["ONPUBGUI_SS_P"] ) ) {
                    $page = $_SESSION["ONPUBGUI_SS_P"];
                }

                if ( isset( $_SESSION["ONPUBGUI_SS_S"] ) ) {
                    $keywords = $_SESSION["ONPUBGUI_SS_S"];
                }

                if ( isset( $_SESSION["ONPUBGUI_SS_F"] ) ) {
                    $fullTextSearch = $_SESSION["ONPUBGUI_SS_F"];
                }

                if ( isset( $_SESSION["ONPUBGUI_SS_WID"] ) ) {
                    $websiteID = $_SESSION["ONPUBGUI_SS_WID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $select = new OnpubSectionSelect( $pdo, $orderBy, $order, $page, $keywords, $fullTextSearch, $websiteID );

                try {
                    $select->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "DataRestore":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $upload = new OnpubDataRestore( $pdo );

                try {
                    $upload->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "WebsiteCreate":
                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $owebsite = new OnpubWebsite();

                $create = new OnpubWebsiteCreate( $pdo, $owebsite );

                try {
                    $create->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "WebsiteSelect":
                if ( isset( $_GET["orderBy"] ) && isset( $_GET["order"] ) ) {
                    $orderBy = $_GET["orderBy"];
                    $order = $_GET["order"];
                    $_SESSION["ONPUBGUI_WS_OB"] = $orderBy;
                    $_SESSION["ONPUBGUI_WS_O"] = $order;
                }
                else {
                    $orderBy = null;
                    $order = null;
                }

                if ( isset( $_GET["page"] ) ) {
                    $page = $_GET["page"];
                    $_SESSION["ONPUBGUI_WS_P"] = $page;
                }
                else {
                    $page = null;
                }

                if ( isset( $_GET["keywords"] ) ) {
                    $keywords = $_GET["keywords"];

                    if ( isset( $_SESSION["ONPUBGUI_WS_S"] ) ) {
                        if ( $_GET["keywords"] != $_SESSION["ONPUBGUI_WS_S"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_WS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_WS_S"] = $keywords;
                }
                else {
                    $keywords = null;
                }

                if ( isset( $_GET["fullTextSearch"] ) ) {
                    $fullTextSearch = $_GET["fullTextSearch"];
                    $_SESSION["ONPUBGUI_WS_F"] = $fullTextSearch;
                }
                else {
                    $fullTextSearch = null;
                    $_SESSION["ONPUBGUI_WS_F"] = $fullTextSearch;
                }

                if ( isset( $_GET["websiteID"] ) ) {
                    $websiteID = $_GET["websiteID"];

                    if ( isset( $_SESSION["ONPUBGUI_WS_WID"] ) ) {
                        if ( $_GET["websiteID"] != $_SESSION["ONPUBGUI_WS_WID"] ) {
                            $page = null;
                            $_SESSION["ONPUBGUI_WS_P"] = null;
                        }
                    }

                    $_SESSION["ONPUBGUI_WS_WID"] = $websiteID;
                }
                else {
                    $websiteID = null;
                }

                if ( isset( $_SESSION["ONPUBGUI_WS_OB"] ) && isset( $_SESSION["ONPUBGUI_WS_O"] ) ) {
                    $orderBy = $_SESSION["ONPUBGUI_WS_OB"];
                    $order = $_SESSION["ONPUBGUI_WS_O"];
                }

                if ( isset( $_SESSION["ONPUBGUI_WS_P"] ) ) {
                    $page = $_SESSION["ONPUBGUI_WS_P"];
                }

                if ( isset( $_SESSION["ONPUBGUI_WS_S"] ) ) {
                    $keywords = $_SESSION["ONPUBGUI_WS_S"];
                }

                if ( isset( $_SESSION["ONPUBGUI_WS_F"] ) ) {
                    $fullTextSearch = $_SESSION["ONPUBGUI_WS_F"];
                }

                if ( isset( $_SESSION["ONPUBGUI_WS_WID"] ) ) {
                    $websiteID = $_SESSION["ONPUBGUI_WS_WID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                $select = new OnpubWebsiteSelect( $pdo, $orderBy, $order, $page, $keywords, $fullTextSearch, $websiteID );

                try {
                    $select->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            case "WebsiteEdit":
                if ( isset( $_GET["websiteID"] ) ) {
                    $websiteID = $_GET["websiteID"];
                }
                else {
                    $websiteID = $_GET["ID"];
                }

                $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );

                $owebsite = new OnpubWebsite();
                $owebsite->setID( $websiteID );

                $edit = new OnpubWebsiteEdit( $pdo, $owebsite );

                try {
                    $edit->display();
                }
                catch ( PDOException $e ) {
                    $widget = new OnpubPDOExceptionWidget( $e );
                    $widget->display();
                    $pdo = null;
                    exit( $e->getCode() );
                }

                $pdo = null;
            break;

            default:
                if ( !$loginStatus ) {
                    $login = new OnpubLogin();
                    $login->display();
                }
                else {
                    $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
                    $welcome = new OnpubWelcome( $pdo );
                    $welcome->display();
                    $pdo = null;
                }
            break;
        }
    }
    else {
        if ( !$loginStatus ) {
            $login = new OnpubLogin();
            $login->display();
        }
        else {
            $pdo = new PDO( $dsn, $username, $password ); $pdo->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT );
            $welcome = new OnpubWelcome( $pdo );

            try {
                $welcome->display();
            }
            catch ( PDOException $e ) {
                $widget = new OnpubPDOExceptionWidget( $e );
                $widget->display();
                $pdo = null;
                exit( $e->getCode() );
            }

            $pdo = null;
        }
    }
}

?>
